@@ -436,7 +436,7 @@ class Bot:
             except:
                 pass
             return 0, "KeyboardInterrupt"
-        except BaseException as e:
+        except (BaseException, asyncio.streams.IncompleteReadError) as e:
             
             if self.stopped:
                 try:
@@ -450,8 +450,11 @@ class Bot:
                 except:
                     pass
             
-            self.log_error(e)
-            self.log("Due to above error, the bot will reconnect to the gateway.", severity = log_severity.important)
+            if isinstance(e, asyncio.streams.IncompleteReadError):
+                self.log("Reconnecting due to an IncompleteReadError: %s" % e)
+            else:
+                self.log_error(e)
+                self.log("Due to above error, the bot will reconnect to the gateway.", severity = log_severity.important)
             
             self.ready = False
             return await self._run()
